@@ -112,12 +112,13 @@ static void         thunar_details_view_append_menu_items       (ThunarStandardV
                                                                  GtkAccelGroup          *accel_group);
 
 
-
 struct _ThunarDetailsViewClass
 {
   ThunarStandardViewClass __parent__;
 };
 
+
+
 struct _ThunarDetailsView
 {
   ThunarStandardView __parent__;
@@ -133,13 +134,17 @@ struct _ThunarDetailsView
 
   /* whether the most recent item activation used a mouse button press */
   gboolean           button_pressed;
+
+  /* event source id for thunar_details_view_zoom_level_changed_reload_fixed_columns */
+  guint idle_id;
+
 };
 
 
 
 static XfceGtkActionEntry thunar_details_view_action_entries[] =
 {
-    { THUNAR_DETAILS_VIEW_ACTION_CONFIGURE_COLUMNS, "<Actions>/ThunarStandardView/configure-columns", "", XFCE_GTK_MENU_ITEM , N_ ("Configure _Columns..."), N_("Configure the columns in the detailed list view"), NULL, G_CALLBACK (thunar_show_column_editor), },
+    { THUNAR_DETAILS_VIEW_ACTION_CONFIGURE_COLUMNS,  "<Actions>/ThunarStandardView/configure-columns", "", XFCE_GTK_MENU_ITEM , N_ ("Configure _Columns..."), N_("Configure the columns in the detailed list view"), NULL, G_CALLBACK (thunar_show_column_editor), },
 };
 
 #define get_action_entry(id) xfce_gtk_get_action_entry_by_id(thunar_details_view_action_entries,G_N_ELEMENTS(thunar_details_view_action_entries),id)
@@ -386,6 +391,9 @@ thunar_details_view_finalize (GObject *object)
   g_signal_handlers_disconnect_by_func (G_OBJECT (details_view->column_model), thunar_details_view_columns_changed, details_view);
   g_object_unref (G_OBJECT (details_view->column_model));
 
+  if (details_view->idle_id)
+    g_source_remove (details_view->idle_id);
+
   (*G_OBJECT_CLASS (thunar_details_view_parent_class)->finalize) (object);
 }
 
@@ -659,6 +667,9 @@ thunar_details_view_button_press_event (GtkTreeView       *tree_view,
       && !gtk_tree_view_get_path_at_pos (tree_view, event->x, event->y, &path, &column, NULL, NULL))
       gtk_tree_selection_unselect_all (selection);
 
+  /* make sure that rubber banding is enabled */
+  gtk_tree_view_set_rubber_banding (tree_view, TRUE);
+
   /* if the user clicked on a row with the left button */
   if (path != NULL && event->type == GDK_BUTTON_PRESS && event->button == 1)
     {
@@ -669,9 +680,6 @@ thunar_details_view_button_press_event (GtkTreeView       *tree_view,
       /* grab the tree view */
       gtk_widget_grab_focus (GTK_WIDGET (tree_view));
 
-      /* make sure that rubber banding is enabled */
-      gtk_tree_view_set_rubber_banding (tree_view, TRUE);
-
       gtk_tree_view_get_cursor (tree_view, &cursor_path, NULL);
       if (cursor_path != NULL)
         {
@@ -708,27 +716,15 @@ thunar_details_view_button_press_event (GtkTreeView       *tree_view,
         }
       else
         {
-          if (column != name_column)
+          /* select the clicked path if necessary */
+          if (!gtk_tree_selection_path_is_selected (selection, path))
             {
-              /* if the clicked path is not selected, unselect all other paths */
-              if (!gtk_tree_selection_path_is_selected (selection, path))
-                gtk_tree_selection_unselect_all (selection);
-
-              /* queue the menu popup */
-              thunar_standard_view_queue_popup (THUNAR_STANDARD_VIEW (details_view), event);
+              gtk_tree_selection_unselect_all (selection);
+              gtk_tree_selection_select_path (selection, path);
             }
-          else
-            {
-              /* select the clicked path if necessary */
-              if (!gtk_tree_selection_path_is_selected (selection, path))
-                {
-                  gtk_tree_selection_unselect_all (selection);
-                  gtk_tree_selection_select_path (selection, path);
-                }
 
-              /* show the context menu */
-              thunar_standard_view_context_menu (THUNAR_STANDARD_VIEW (details_view));
-            }
+          /* show the context menu */
+          thunar_standard_view_queue_popup (THUNAR_STANDARD_VIEW (details_view), event);
           gtk_tree_path_free (path);
         }
 
@@ -885,6 +881,7 @@ thunar_details_view_zoom_level_changed_reload_fixed_columns (gpointer data)
   _thunar_return_val_if_fail (THUNAR_IS_DETAILS_VIEW (details_view), FALSE);
 
   thunar_details_view_set_fixed_columns (details_view, TRUE);
+  details_view->idle_id = 0;
   return FALSE;
 }
 
@@ -915,7 +912,7 @@ thunar_details_view_zoom_level_changed (ThunarDetailsView *details_view)
   if (fixed_columns_used)
     {
       /* Call when idle to ensure that gtk_tree_view_column_queue_resize got finished */
-      gdk_threads_add_idle (thunar_details_view_zoom_level_changed_reload_fixed_columns, details_view);
+      details_view->idle_id = gdk_threads_add_idle (thunar_details_view_zoom_level_changed_reload_fixed_columns, details_view);
     }
 }
 
