@@ -45,6 +45,7 @@ typedef struct _ThunarFile      ThunarFile;
  * ThunarFileDateType:
  * @THUNAR_FILE_DATE_ACCESSED : date of last access to the file.
  * @THUNAR_FILE_DATE_CHANGED  : date of last change to the file meta data or the content.
+ * @THUNAR_FILE_DATE_CREATED  : date of file creation.
  * @THUNAR_FILE_DATE_MODIFIED : date of last modification of the file's content.
  *
  * The various dates that can be queried about a #ThunarFile. Note, that not all
@@ -55,6 +56,7 @@ typedef enum
 {
   THUNAR_FILE_DATE_ACCESSED,
   THUNAR_FILE_DATE_CHANGED,
+  THUNAR_FILE_DATE_CREATED,
   THUNAR_FILE_DATE_MODIFIED,
 } ThunarFileDateType;
 
