@@ -87,8 +87,6 @@ thunar_gtk_menu_thunarx_menu_item_new (GObject      *thunarx_menu_item,
   GList        *children;
   GList        *lp;
   GtkWidget    *submenu;
-  GtkWidget    *image;
-  GIcon        *icon; 
 
   g_return_val_if_fail (THUNARX_IS_MENU_ITEM (thunarx_menu_item), NULL);
 
@@ -102,11 +100,9 @@ thunar_gtk_menu_thunarx_menu_item_new (GObject      *thunarx_menu_item,
                 NULL);
 
   accel_path = g_strconcat ("<Actions>/ThunarActions/", name, NULL);
-  icon = g_icon_new_for_string (icon_name, NULL);
-  image = gtk_image_new_from_gicon (icon,GTK_ICON_SIZE_MENU);
-  gtk_menu_item = xfce_gtk_image_menu_item_new (label_text, tooltip_text, accel_path,
-                                                G_CALLBACK (thunarx_menu_item_activate),
-                                                G_OBJECT (thunarx_menu_item), image, menu_to_append_item);
+  gtk_menu_item = xfce_gtk_image_menu_item_new_from_icon_name (label_text, tooltip_text, accel_path,
+                                                               G_CALLBACK (thunarx_menu_item_activate),
+                                                               G_OBJECT (thunarx_menu_item), icon_name, menu_to_append_item);
 
   /* recursively add submenu items if any */
   if (gtk_menu_item != NULL && thunarx_menu != NULL)
@@ -123,7 +119,6 @@ thunar_gtk_menu_thunarx_menu_item_new (GObject      *thunarx_menu_item,
   g_free (label_text);
   g_free (tooltip_text);
   g_free (icon_name);
-  g_object_unref (icon);
 
   return gtk_menu_item;
 }
@@ -172,33 +167,6 @@ thunar_gtk_menu_run (GtkMenu *menu)
 
 
 
-#if GTK_CHECK_VERSION (3, 24, 8)
-static void
-moved_to_rect_cb (GdkWindow          *window,
-                  const GdkRectangle *flipped_rect,
-                  const GdkRectangle *final_rect,
-                  gboolean            flipped_x,
-                  gboolean            flipped_y,
-                  GtkMenu            *menu)
-{
-    g_signal_emit_by_name (menu, "popped-up", 0, flipped_rect, final_rect, flipped_x, flipped_y);
-    g_signal_stop_emission_by_name (window, "moved-to-rect");
-}
-
-
-
-static void
-popup_menu_realized (GtkWidget *menu,
-                     gpointer   user_data)
-{
-    GdkWindow *toplevel = gtk_widget_get_window (gtk_widget_get_toplevel (menu));
-    g_signal_handlers_disconnect_by_func (toplevel, moved_to_rect_cb, menu);
-    g_signal_connect (toplevel, "moved-to-rect", G_CALLBACK (moved_to_rect_cb), menu);
-}
-#endif
-
-
-
 /**
  * thunar_gtk_menu_run_at_event:
  * @menu  : a #GtkMenu.
@@ -213,8 +181,7 @@ popup_menu_realized (GtkWidget *menu,
  *
  **/
 void
-thunar_gtk_menu_run_at_event (GtkMenu *menu,
-                              GdkEvent *event)
+thunar_gtk_menu_run_at_event (GtkMenu *menu, GdkEvent *event)
 {
   GMainLoop *loop;
   gulong     signal_id;
@@ -227,13 +194,6 @@ thunar_gtk_menu_run_at_event (GtkMenu *menu,
   /* run an internal main loop */
   loop = g_main_loop_new (NULL, FALSE);
   signal_id = g_signal_connect_swapped (G_OBJECT (menu), "deactivate", G_CALLBACK (g_main_loop_quit), loop);
-
-#if GTK_CHECK_VERSION (3, 24, 8)
-    /* Workaround for incorrect popup menus size */
-    g_signal_connect (G_OBJECT (menu), "realize", G_CALLBACK (popup_menu_realized), NULL);
-    gtk_widget_realize (GTK_WIDGET (menu));
-#endif
-
   gtk_menu_popup_at_pointer (menu, event);
   gtk_menu_reposition (menu);
   gtk_grab_add (GTK_WIDGET (menu));
