@@ -1269,8 +1269,6 @@ thunar_tree_view_context_menu (ThunarTreeView *view,
                                                 | THUNAR_MENU_SECTION_RENAME
                                                 | THUNAR_MENU_SECTION_CUSTOM_ACTIONS);
         }
-      thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_MOUNTABLE);
-      thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_PROPERTIES);
     }
   else
     {
@@ -1279,11 +1277,11 @@ thunar_tree_view_context_menu (ThunarTreeView *view,
       thunar_launcher_append_menu_item (view->launcher, GTK_MENU_SHELL (context_menu), THUNAR_LAUNCHER_ACTION_OPEN_IN_TAB, TRUE);
       thunar_launcher_append_menu_item (view->launcher, GTK_MENU_SHELL (context_menu), THUNAR_LAUNCHER_ACTION_OPEN_IN_WINDOW, TRUE);
       xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (context_menu));
-      thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_MOUNTABLE);
-      if (thunar_device_is_mounted (device))
-        thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_PROPERTIES);
     }
 
+  thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_MOUNTABLE);
+  thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_PROPERTIES);
+
   thunar_menu_hide_accel_labels (context_menu);
   gtk_widget_show_all (GTK_WIDGET (context_menu));
   window = gtk_widget_get_toplevel (GTK_WIDGET (view));
@@ -1644,19 +1642,24 @@ THUNAR_THREADS_ENTER
       gtk_tree_view_set_cursor (GTK_TREE_VIEW (view), view->select_path, NULL, FALSE);
       gtk_tree_path_free (view->select_path);
       view->select_path = NULL;
-      return TRUE;
+      return FALSE;
     }
 
   /* verify that we still have a current directory */
   if (G_UNLIKELY (view->current_directory == NULL))
-    return TRUE;
+    return FALSE;
 
   /* get the preferred toplevel path for the current directory */
   path = thunar_tree_view_get_preferred_toplevel_path (view, view->current_directory);
 
-  /* fallback to a newly created root node */
+  /* if no path could be determined, remove the current selection and return */
   if (path == NULL)
-    path = gtk_tree_path_new_first ();
+    {
+      GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
+      if (GTK_IS_TREE_SELECTION (selection))
+        gtk_tree_selection_unselect_all (selection);
+      return FALSE;
+    }
 
   gtk_tree_model_get_iter (GTK_TREE_MODEL (view->model), &iter, path);
   gtk_tree_path_free (path);
