@@ -53,6 +53,7 @@ typedef enum
   THUNAR_WINDOW_ACTION_VIEW_MENU,
   THUNAR_WINDOW_ACTION_RELOAD,
   THUNAR_WINDOW_ACTION_RELOAD_ALT,
+  THUNAR_WINDOW_ACTION_VIEW_SPLIT,
   THUNAR_WINDOW_ACTION_VIEW_LOCATION_SELECTOR_MENU,
   THUNAR_WINDOW_ACTION_VIEW_LOCATION_SELECTOR_PATHBAR,
   THUNAR_WINDOW_ACTION_VIEW_LOCATION_SELECTOR_TOOLBAR,
@@ -64,12 +65,9 @@ typedef enum
   THUNAR_WINDOW_ACTION_VIEW_MENUBAR,
   THUNAR_WINDOW_ACTION_SHOW_HIDDEN,
   THUNAR_WINDOW_ACTION_ZOOM_IN,
-  THUNAR_WINDOW_ACTION_ZOOM_IN_ALT_1,
-  THUNAR_WINDOW_ACTION_ZOOM_IN_ALT_2,
+  THUNAR_WINDOW_ACTION_ZOOM_IN_ALT,
   THUNAR_WINDOW_ACTION_ZOOM_OUT,
-  THUNAR_WINDOW_ACTION_ZOOM_OUT_ALT,
   THUNAR_WINDOW_ACTION_ZOOM_RESET,
-  THUNAR_WINDOW_ACTION_ZOOM_RESET_ALT,
   THUNAR_WINDOW_ACTION_CLEAR_DIRECTORY_SPECIFIC_SETTINGS,
   THUNAR_WINDOW_ACTION_VIEW_AS_ICONS,
   THUNAR_WINDOW_ACTION_VIEW_AS_DETAILED_LIST,
@@ -126,8 +124,6 @@ void                      thunar_window_redirect_menu_tooltips_to_statusbar (Thu
                                                                              GtkMenu             *menu);
 const XfceGtkActionEntry* thunar_window_get_action_entry                    (ThunarWindow        *window,
                                                                              ThunarWindowAction   action);
- void                     thunar_window_select_files                        (ThunarWindow         *window,
-                                                                             GList                *path_list);
 G_END_DECLS;
 
 #endif /* !__THUNAR_WINDOW_H__ */
